//-----------------------------------------------------------------------------
// This file holds all custom weapon stuffs.
//-----------------------------------------------------------------------------
PrecacheModel("models/weapons/c_models/c_bigaxe/c_bigaxe.mdl")
PrecacheModel("models/weapons/c_models/c_medic_wood_dart_rifle/c_medic_wood_dart_rifle.mdl")

enum GTFW_MODELS_CUSTOM_WEAPONS
{
	DEMO_BIGAXE		= "models/weapons/c_models/c_bigaxe/c_bigaxe.mdl",
	SCOUT_DARTGUN	= "models/weapons/c_models/c_medic_wood_dart_rifle/c_medic_wood_dart_rifle.mdl"
}

//-----------------------------------------------------------------------------
// Example weapon #1. This one is the Scout's Medieval Crossbow
// It is based off the Crusader's Crossbow. Main thing is it slows the player while reloading.
//-----------------------------------------------------------------------------
function CW_Stats_Example_Scout_Medieval_Crossbow(weapon, player)
{
	weapon.AddAttribute("maxammo primary reduced", 0.45, -1)
	weapon.AddAttribute("override projectile type", 8, -1)
	weapon.AddAttribute("clip size upgrade atomic", 2, -1)
	weapon.AddAttribute("damage penalty", 0.67, -1)
	NetProps.SetPropIntArray(player, "localdata.m_iAmmo", 15, 1)
	NetProps.SetPropInt(weapon, "LocalWeaponData.m_iClip1", 3)
	if( weapon.ValidateScriptScope() )
	{
		const THINK_SCOUTWEAPONRELOAD_DELAY = 0.25
		
		local entityscript = weapon.GetScriptScope()
		entityscript["think_SlowPlayerDuringReload"] <- function()
		{
			if ( NetProps.GetPropInt(weapon, "m_iReloadMode") == 2)
			{
				player.AddCustomAttribute("move speed penalty", 0.5, -1)
			}
			else if ( NetProps.GetPropInt(weapon, "m_iReloadMode") != 2)
			{
				player.RemoveCustomAttribute("move speed penalty")
			}
			return THINK_SCOUTWEAPONRELOAD_DELAY
		}
		AddThinkToEnt(weapon, "think_SlowPlayerDuringReload")
	}
}

//-----------------------------------------------------------------------------
//Registers this weapon as "Kritzader's Crossbow"...
// In this way, we can just use GiveWeapon() to add it quickly, without hassle!
//-----------------------------------------------------------------------------
	RegisterCustomWeapon("Kritzader's Crossbow", "Crossbow", GTFW_MODELS_CUSTOM_WEAPONS.SCOUT_DARTGUN, GTFW_ARMS.MEDIC, CW_Stats_Example_Scout_Medieval_Crossbow)


//-----------------------------------------------------------------------------
// Example weapon #2. This one turns you into the Horseless Headless Horsemann.
// It is based off the Demo's Headtaker.
//-----------------------------------------------------------------------------
function CW_Stats_Example_Headless_Hatman(weapon, player)
{
	player.SetCustomModelWithClassAnimations("models/bots/headless_hatman.mdl") //sets model to Horsemann
	NetProps.SetPropInt(player, "m_PlayerClass.m_iClass", 4)	//Forcefully sets tfclass to CIVILIAN
	
//Our stats
	weapon.ReapplyProvision()	//clears any stats cache on weapon
	weapon.AddAttribute("hidden maxhealth non buffed", (player.GetMaxHealth()*10), -1)	//using this attribute because it can't be overhealed
	player.SetHealth(player.GetMaxHealth())
	weapon.AddAttribute("move speed bonus", 1.25, -1)
	weapon.AddAttribute("damage bonus", 99, -1)	
	
	player.Weapon_Switch(weapon)	//vscript built-in function. Forces switch to handle 'weapon'.
	player.AddCond(41)	//locks player in melee
	
//Our effects
	//DoEntFire("!self", "SetModelScale", "1.25", 0, null, player)	//sets player scale
	player.AddCustomAttribute("SPELL: set Halloween footstep type", 2, -1)
	player.AddCustomAttribute("set item tint RGB", 9109759, -1)
	DoEntFire("!self", "SetForcedTauntCam", "1", 0, null, player)	//sets third person mode
	
// Deletes all cosmetics from the player. Doesn't include "tf_powerup_bottle", "tf_wearable_demoshield", etc.
	for (local i = 0; i < 10; i++)
	{
		local wearable = Entities.FindByNameWithin(this, "tf_wearable", this.GetLocalOrigin(), 128)

		if ( wearable != null && NetProps.GetPropEntity(wearable, "m_hOwnerEntity") == this )
		{
			wearable.Kill()
		}
		else
		{
			break
		}
	}
}

//-----------------------------------------------------------------------------
//Registers this weapon as "Horseless Headless Horsemann's Hell-Maker"...
//-----------------------------------------------------------------------------
RegisterCustomWeapon("Horseless Headless Horsemann's Hell-Maker", "HHHH", GTFW_MODELS_CUSTOM_WEAPONS.DEMO_BIGAXE, null, CW_Stats_Example_Headless_Hatman)
